Struct ShardedLockReadGuard
struct ShardedLockReadGuard<'a, T: ?Sized> { ... }
A guard used to release the shared read access of a ShardedLock when dropped.
Implementations
impl<'a, T> Freeze for ShardedLockReadGuard<'a, T>
impl<'a, T> RefUnwindSafe for ShardedLockReadGuard<'a, T>
impl<'a, T> Send for ShardedLockReadGuard<'a, T>
impl<'a, T> Unpin for ShardedLockReadGuard<'a, T>
impl<'a, T> UnsafeUnpin for ShardedLockReadGuard<'a, T>
impl<'a, T> UnwindSafe for ShardedLockReadGuard<'a, T>
impl<P, T> Receiver for ShardedLockReadGuard<'a, T>
impl<T> Any for ShardedLockReadGuard<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ShardedLockReadGuard<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ShardedLockReadGuard<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ShardedLockReadGuard<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToString for ShardedLockReadGuard<'a, T>
fn to_string(self: &Self) -> String
impl<T, U> Into for ShardedLockReadGuard<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ShardedLockReadGuard<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ShardedLockReadGuard<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: ?Sized + Sync> Sync for ShardedLockReadGuard<'_, T>
impl<T: ?Sized + fmt::Display> Display for ShardedLockReadGuard<'_, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: ?Sized> Deref for ShardedLockReadGuard<'_, T>
fn deref(self: &Self) -> &T
impl<T: fmt::Debug> Debug for ShardedLockReadGuard<'_, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result