Struct ShardedLockWriteGuard

struct ShardedLockWriteGuard<'a, T: ?Sized> { ... }

A guard used to release the exclusive write access of a ShardedLock when dropped.

Implementations

impl<'a, T> Freeze for ShardedLockWriteGuard<'a, T>

impl<'a, T> RefUnwindSafe for ShardedLockWriteGuard<'a, T>

impl<'a, T> Send for ShardedLockWriteGuard<'a, T>

impl<'a, T> Unpin for ShardedLockWriteGuard<'a, T>

impl<'a, T> UnsafeUnpin for ShardedLockWriteGuard<'a, T>

impl<'a, T> UnwindSafe for ShardedLockWriteGuard<'a, T>

impl<P, T> Receiver for ShardedLockWriteGuard<'a, T>

impl<T> Any for ShardedLockWriteGuard<'a, T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ShardedLockWriteGuard<'a, T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ShardedLockWriteGuard<'a, T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for ShardedLockWriteGuard<'a, T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for ShardedLockWriteGuard<'a, T>

fn to_string(self: &Self) -> String

impl<T, U> Into for ShardedLockWriteGuard<'a, T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ShardedLockWriteGuard<'a, T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ShardedLockWriteGuard<'a, T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: ?Sized + Sync> Sync for ShardedLockWriteGuard<'_, T>

impl<T: ?Sized + fmt::Display> Display for ShardedLockWriteGuard<'_, T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T: ?Sized> Deref for ShardedLockWriteGuard<'_, T>

fn deref(self: &Self) -> &T

impl<T: ?Sized> DerefMut for ShardedLockWriteGuard<'_, T>

fn deref_mut(self: &mut Self) -> &mut T

impl<T: ?Sized> Drop for ShardedLockWriteGuard<'_, T>

fn drop(self: &mut Self)

impl<T: fmt::Debug> Debug for ShardedLockWriteGuard<'_, T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result