Struct Unparker
struct Unparker { ... }
Unparks a thread parked by the associated Parker.
Implementations
impl Unparker
fn unpark(self: &Self)Atomically makes the token available if it is not already.
This method will wake up the thread blocked on
parkorpark_timeout, if there is any.Examples
use thread; use Duration; use Parker; let p = new; let u = p.unparker.clone; spawn; // Wakes up when `u.unpark()` provides the token. p.park; # sleep; // wait for background threads closed: https://github.com/rust-lang/miri/issues/1371fn into_raw(this: Unparker) -> *const ()Converts an
Unparkerinto a raw pointer.Examples
use ; let p = new; let u = p.unparker.clone; let raw = into_raw; # let _ = unsafe ;unsafe fn from_raw(ptr: *const ()) -> UnparkerConverts a raw pointer into an
Unparker.Safety
This method is safe to use only with pointers returned by
Unparker::into_raw.Examples
use ; let p = new; let u = p.unparker.clone; let raw = into_raw; let u = unsafe ;
impl Clone for Unparker
fn clone(self: &Self) -> Unparker
impl Debug for Unparker
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Unparker
impl RefUnwindSafe for Unparker
impl Send for Unparker
impl Sync for Unparker
impl Unpin for Unparker
impl UnsafeUnpin for Unparker
impl UnwindSafe for Unparker
impl<T> Any for Unparker
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Unparker
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Unparker
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Unparker
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Unparker
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Unparker
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Unparker
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Unparker
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Unparker
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>