Struct ScopedThreadBuilder

struct ScopedThreadBuilder<'scope, 'env> { ... }

Configures the properties of a new thread.

The two configurable properties are:

The spawn method will take ownership of the builder and return an io::Result of the thread handle with the given configuration.

The Scope::spawn method uses a builder with default configuration and unwraps its return value. You may want to use this builder when you want to recover from a failure to launch a thread.

Examples

use crossbeam_utils::thread;

thread::scope(|s| {
    s.builder()
        .spawn(|_| println!("Running a child thread"))
        .unwrap();
}).unwrap();

Implementations

impl<'scope, 'env> ScopedThreadBuilder<'scope, 'env>

fn name(self: Self, name: String) -> ScopedThreadBuilder<'scope, 'env>

Sets the name for the new thread.

The name must not contain null bytes (\0).

For more information about named threads, see here.

Examples

use crossbeam_utils::thread;
use std::thread::current;

thread::scope(|s| {
    s.builder()
        .name("my thread".to_string())
        .spawn(|_| assert_eq!(current().name(), Some("my thread")))
        .unwrap();
}).unwrap();
fn stack_size(self: Self, size: usize) -> ScopedThreadBuilder<'scope, 'env>

Sets the size of the stack for the new thread.

The stack size is measured in bytes.

For more information about the stack size for threads, see here.

Examples

use crossbeam_utils::thread;

thread::scope(|s| {
    s.builder()
        .stack_size(32 * 1024)
        .spawn(|_| println!("Running a child thread"))
        .unwrap();
}).unwrap();
fn spawn<F, T>(self: Self, f: F) -> Result<ScopedJoinHandle<'scope, T>>
where
    F: FnOnce(&Scope<'env>) -> T + Send + 'env,
    T: Send + 'env

Spawns a scoped thread with this configuration.

The scoped thread is passed a reference to this scope as an argument, which can be used for spawning nested threads.

The returned handle can be used to manually join the thread before the scope exits.

Errors

Unlike the Scope::spawn method, this method yields an io::Result to capture any failure to create the thread at the OS level.

Panics

Panics if a thread name was set and it contained null bytes.

Examples

use crossbeam_utils::thread;

thread::scope(|s| {
    let handle = s.builder()
        .spawn(|_| {
            println!("A child thread is running");
            42
        })
        .unwrap();

    // Join the thread and retrieve its result.
    let res = handle.join().unwrap();
    assert_eq!(res, 42);
}).unwrap();

impl<'scope, 'env> Debug for ScopedThreadBuilder<'scope, 'env>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'scope, 'env> Freeze for ScopedThreadBuilder<'scope, 'env>

impl<'scope, 'env> RefUnwindSafe for ScopedThreadBuilder<'scope, 'env>

impl<'scope, 'env> Send for ScopedThreadBuilder<'scope, 'env>

impl<'scope, 'env> Sync for ScopedThreadBuilder<'scope, 'env>

impl<'scope, 'env> Unpin for ScopedThreadBuilder<'scope, 'env>

impl<'scope, 'env> UnsafeUnpin for ScopedThreadBuilder<'scope, 'env>

impl<'scope, 'env> UnwindSafe for ScopedThreadBuilder<'scope, 'env>

impl<T> Any for ScopedThreadBuilder<'scope, 'env>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ScopedThreadBuilder<'scope, 'env>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ScopedThreadBuilder<'scope, 'env>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for ScopedThreadBuilder<'scope, 'env>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for ScopedThreadBuilder<'scope, 'env>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ScopedThreadBuilder<'scope, 'env>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ScopedThreadBuilder<'scope, 'env>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>